summaryrefslogtreecommitdiff
path: root/src/cairo-tee-surface.c
diff options
context:
space:
mode:
authorM Joonas Pihlaja <jpihlaja@cc.helsinki.fi>2009-10-22 02:13:36 +0300
committerM Joonas Pihlaja <jpihlaja@cc.helsinki.fi>2009-10-22 02:29:47 +0300
commit43a775f60da57206b194039cd5d8b6a735284c45 (patch)
treed6336bb46cc3927819c1341900ae80ca54b71abc /src/cairo-tee-surface.c
parentdf357f26ff72571acb840715efa4930054d4fdbe (diff)
downloadcairo-43a775f60da57206b194039cd5d8b6a735284c45.tar.gz
[meta] Rename cairo_meta_surface_t to cairo_recording_surface_t.
The new name is more descriptive than the rather opaque meta surface. Discussed with vigour on the mailing list and #cairo: http://lists.cairographics.org/archives/cairo/2009-July/017571.html
Diffstat (limited to 'src/cairo-tee-surface.c')
-rw-r--r--src/cairo-tee-surface.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/cairo-tee-surface.c b/src/cairo-tee-surface.c
index 56f3cc26e..1111fa1b4 100644
--- a/src/cairo-tee-surface.c
+++ b/src/cairo-tee-surface.c
@@ -159,14 +159,14 @@ _cairo_tee_surface_snapshot (void *abstract_surface)
cairo_surface_wrapper_t *slaves;
int num_slaves, n;
- /* we prefer to use a meta surface for our snapshots */
- if (_cairo_surface_is_meta (surface->master.target))
+ /* we prefer to use a recording surface for our snapshots */
+ if (_cairo_surface_is_recording (surface->master.target))
return _cairo_surface_wrapper_snapshot (&surface->master);
num_slaves = _cairo_array_num_elements (&surface->slaves);
slaves = _cairo_array_index (&surface->slaves, 0);
for (n = 0; n < num_slaves; n++) {
- if (_cairo_surface_is_meta (slaves[n].target))
+ if (_cairo_surface_is_recording (slaves[n].target))
return _cairo_surface_wrapper_snapshot (&slaves[n]);
}